@@ -66,17 +66,16 @@ class Composer:
         price: float,
         quantity: float,
         is_buy: bool,
-        leverage: float = 1,
-        is_reduce_only: bool = False
+        **kwargs
     ):
         # load denom metadata
         denom = Denom.load_market(self.network, market_id)
         print('Loaded market metadata for', denom.description)
 
-        if is_reduce_only is True:
+        if kwargs.get("is_reduce_only", True):
             margin = 0
         else:
-            margin = derivative_margin_to_backend(price, quantity, leverage, denom)
+            margin = derivative_margin_to_backend(price, quantity, kwargs.get("leverage"), denom)
 
         # prepare values
         price = derivative_price_to_backend(price, denom)
@@ -206,8 +205,7 @@ class Composer:
         price: float,
         quantity: float,
         is_buy: bool,
-        is_reduce_only: bool = False,
-        leverage: float = 1
+        **kwargs
     ):
         return injective_exchange_tx_pb.MsgCreateDerivativeLimitOrder(
             sender=sender,
@@ -217,9 +215,9 @@ class Composer:
                 fee_recipient=fee_recipient,
                 price=price,
                 quantity=quantity,
-                leverage=leverage,
                 is_buy=is_buy,
-                is_reduce_only=is_reduce_only
+                leverage=kwargs.get("leverage"),
+                is_reduce_only=kwargs.get("is_reduce_only")
             )
         )
 
@@ -344,6 +342,21 @@ class Composer:
             amount=self.Coin(amount=be_amount, denom=peggy_denom)
         )
 
+    def MsgBid(
+        self,
+        sender: str,
+        bid_amount: float,
+        round: float
+    ):
+
+        be_amount = amount_to_backend(bid_amount, 18)
+
+        return injective_auction_tx_pb.MsgBid(
+            sender=sender,
+            round=round,
+            bid_amount=self.Coin(amount=be_amount, denom="inj")
+            )
+
     # data field format: [request-msg-header][raw-byte-msg-response]
     # you need to figure out this magic prefix number to trim request-msg-header off the data
     # this method handles only exchange responses
@@ -365,7 +378,8 @@ class Composer:
             "/injective.exchange.v1beta1.MsgWithdraw": injective_exchange_tx_pb.MsgWithdrawResponse,
             "/injective.exchange.v1beta1.MsgSubaccountTransfer": injective_exchange_tx_pb.MsgSubaccountTransferResponse,
             "/injective.exchange.v1beta1.MsgLiquidatePosition": injective_exchange_tx_pb.MsgLiquidatePosition,
-            "/injective.exchange.v1beta1.MsgIncreasePositionMargin": injective_exchange_tx_pb.MsgIncreasePositionMargin
+            "/injective.exchange.v1beta1.MsgIncreasePositionMargin": injective_exchange_tx_pb.MsgIncreasePositionMargin,
+            "/injective.auction.v1beta1.MsgBid": injective_auction_tx_pb.MsgBidResponse,
         }
 
         response = tx_response_pb.TxResponseData.FromString(data)
